import logging
import urllib2

from parallels.operability_check import DomainIssue, Severity, WebsiteAvailabilityIssueType
from parallels.operability_check.utils import http_client

logger = logging.getLogger(__name__)

class WebsiteAvailabilityChecker(object):
	@staticmethod
	def check(domains_to_check):
		client = http_client.HttpClient()
		issues = []

		for domain_to_check in domains_to_check:
			def add_issue(severity, category, problem):
				issues.append(DomainIssue(domain_name=domain_to_check.domain_name, severity=severity, category=category, problem=problem))

			url = "%s://%s/" % (domain_to_check.protocol, domain_to_check.domain_name,)
			try:
				response = client.get(url, domain_to_check.web_server_ip)
				code = str(response.code)
				if len(code) > 0 and code[0] == '5':
					add_issue(
						severity=Severity.ERROR, category=WebsiteAvailabilityIssueType.STATUS_CODE_5xx,
						problem=u"Web server at '%s' returned %s HTTP code for web site at '%s'" % (domain_to_check.web_server_ip, code, url)
					)
			except IOError, e:
				add_issue(
					severity=Severity.ERROR, category=WebsiteAvailabilityIssueType.CONNECTION_ISSUE,
					problem=u"Failed to connect to '%s' to get '%s': %s" % (domain_to_check.web_server_ip, url, str(e.reason if isinstance(e, urllib2.URLError) else e))
				)
			except KeyboardInterrupt:
				# for compatibility with python 2.4
				raise
			except Exception, e:
				logger.debug(u"Exception:", exc_info=e)
				add_issue(
					severity=Severity.WARNING, category=WebsiteAvailabilityIssueType.INTERNAL_ERROR,
					problem=u"An internal error occurred: %s. Unable to check whether the web site is available by '%s' at '%s'" % (str(e), url, domain_to_check.web_server_ip)
				)

		return issues
